from distutils.core import setup

setup(
	name         = 'mi_nester',
	version      = '1.2.0',
	py_modules   = ['mi_nester'],
	author       = 'miki',
	author_email = 'fangyu1313@gmail.com',
	url          = 'https://pypi.python.org/pypi?%3Aaction=pkg_edit&name=mi_nester',
	description  = 'A simple',
)